@@ -43,6 +43,7 @@
 # 08 Jul 2025 by Robin added hostname changer, memory manager.
 # 02 November 2025 by anticapitalista added antix-qogir and antix-kora icons
 # 05 December 2025 by anticapitalista added tab for init services
+# 12 January 2926 by anticapitalista added antix-init-diversity-manager
 #
 # Acknowledgements: Original script by KDulcimer of TinyMe. http://tinyme.mypclinuxos.com
 #################################################################################################################################################
@@ -551,6 +552,13 @@ test -x $66conf_prog && 66conf_entry=$(entry \
     $"Choose s6-66 Startup Services" \
     $"Select what system services should be started automatically when booting antiX (s6-66).")
 
+initmanager_prog=/usr/bin/antix-init-diversity-manager
+test -x $initmanager_prog && initmanager_entry=$(entry \
+    $ICONS/grub-customizer.png \
+    "gksu antix-init-diversity-manager &" \
+    $"Boot Menu init" \
+    $"Select which init(s) should appear in the boot menu")
+
 ufwtoggle_prog=/usr/local/bin/antix_firewall_toggle
 test -x $ufwtoggle_prog && ufwtoggle_entry=$(entry \
     $ICONS/gufw.png \
@@ -1186,7 +1194,7 @@ $(vbox_frame_hbox \
 "$(vbox "$bootrepair_entry" "$menumanager_entry" "$usermanager_entry")" )
 
 $(vbox_frame_hbox \
-"$(vbox "$sysvconf_entry"  "$runitconf_entry")" \
+"$(vbox "$sysvconf_entry"  "$runitconf_entry" "$initmanager_entry")" \
 "$(vbox "$s6conf_entry" "$dinitconf_entry")" )
 
 </notebook>
